<?php
/**
 * @file
 * Admin page/functions to manage ck content injector settings.
 */

/**
 * Form constructor for settings administration.
 *
 * @see ck_content_injector_admin_form_submit()
 */
function ck_content_injector_admin_form($state) {
  $form = array();

  $form['msg'] = array(
    '#type' => 'item',
    '#value' => check_plain('Manage fields to apply CK Content Injector token replacement to, this applies to the BODY by default.'),
  );

  // Get all node types.
  $types = node_type_get_types();

  // Loop types and get all text area (multi row) fields for the node type.
  foreach ($types as $t) {
    $form[$t->type] = array(
      '#type' => 'fieldset',
      '#tree' => TRUE,
      '#title' => check_plain($t->name),
      '#description' => check_plain('Select the fields CK Content Injector tokens should be processed for.'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );

    // Get fields for node type.
    $fields = array();
    $sql = 'SELECT i.* FROM {field_config_instance} AS i JOIN {field_config} AS c ON i.field_id = c.id WHERE c.module = :field AND i.bundle = :type';
    $result = db_query($sql, array(':field' => 'text', ':type' => $t->type));
    while ($r = $result->fetchObject()) {
      $data = unserialize($r->data);
      $fields[$r->field_name] = $data['label'];
    }

    if (count($fields) > 0) {
      $form[$t->type]['fields'] = array(
        '#type' => 'checkboxes',
        '#title' => check_plain('Fields'),
        '#options' => $fields,
        '#default_value' => variable_get('ck_content_injector_' . $t->type . '_fields', array()),
      );
    }
    else {
      $form[$t->type]['fields'] = array(
        '#markup' => '<p>' . check_plain('No compatible text fields defined that can be used with CK Content Injector.') . '</p>',
      );
    }
  }

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Save',
  );

  return $form;
}

/**
 * Form submission for ck_content_injector_admin_form()
 */
function ck_content_injector_admin_form_submit($form, $state) {
  // Get all node types.
  $types = node_type_get_types();

  // Set variables for node type field settings.
  foreach ($types as $t) {
    if (!empty($state['values'][$t->type]['fields'])) {
      variable_set('ck_content_injector_' . $t->type . '_fields', $state['values'][$t->type]['fields']);
    }
    else {
      variable_del('ck_content_injector_' . $t->type . '_fields');
    }
  }
}
