<?php
/**
 * @file
 * Definition of PluginParser
 */

class PluginParser {

  /**
   * Display html for dialog form parameters.
   *
   * @param string $plugin
   *   name of template file
   */
  public function displayForm($plugin) {
    $fields = $this->parseValues($plugin);
    $tidy_ups = array();
    $disabled_fields = array();
    print '<script type="text/javascript">tidyUps={};</script>' . "\n";
    print '<div class="cke_dialog_ui_vbox cke_dialog_page_contents">' . "\n";
    foreach ($fields as $settings) {
      print '<div class="cke_dialog_ui_vbox_child" role="presentation"' . (!empty($settings['disabled']) ? ' style="display: none;"' : '') . '>';
      switch ($settings['type']) {
        case 'dropdown':
        case 'select':
          print '<div class="cke_dialog_ui_select" role="presentation">';
          print '<label>' . htmlspecialchars($settings['label']) . '</label>';
          print '<div class="cke_dialog_ui_select" role="presentation">';
          print '<select class="cke_dialog_ui_input_select" name="field[]" id="t_field_' . $settings['index'] . '" order="' . $settings['index'] . '">';
          foreach ($settings['options'] as $key => $val) {
            print '<option value="' . htmlentities($key) . '">' . htmlspecialchars($val) . '</option>';
          }
          print '</select>';
          print '</div>';
          print '</div>';
          break;

        case 'textbox':
        default:
          print '<div class="cke_dialog_ui_text" role="presentation">';
          print '<label>' . htmlspecialchars($settings['label']) . '</label>';
          print '<div class="cke_dialog_ui_input_text" role="presentation">';
          print '<input class="cke_dialog_ui_input_text" type="text" name="field[]" id="t_field_' . $settings['index'] . '" order="' . $settings['index'] . '" value="" size="' . (!empty($settings['size']) && is_numeric($settings['size']) ? (int) $settings['size'] : 40) . '" required="' . ((!empty($settings['required']) && $settings['required'])? 1 : 0) . '" label="' . $settings['label'] . '" regexp="' . ((!empty($settings['regex']['pattern']))? $settings['regex']['pattern'] : '') . '" regexm="' . ((!empty($settings['regex']['modifier']))? $settings['regex']['modifier'] : '') . '" />';
          print '</div>';
          print '</div>';
          break;
      }
      print '</div>';
      if (!empty($settings['tidy-ups']) && is_array($settings['tidy-ups'])) {
        $tidy_ups[$settings['index']] = $settings['tidy-ups'];
      }
    }
    print '</div>' . "\n";
    print '<script type="text/javascript">tidyUps=' . json_encode($tidy_ups) . '; disabledFields=' . json_encode($disabled_fields) . ';</script>' . "\n";
  }

  /**
   * Get parameter values from template file.
   *
   * @param string $plugin
   *   Name of template file
   *
   * @return array
   *   Template fields
   */
  protected function parseValues($plugin) {
    $template_path = drupal_get_path('module', 'ck_content_injector') . '/injector_templates';
    $get_form_elements = TRUE;
    ob_start();
    require $template_path . '/' . basename($plugin);
    ob_end_clean();
    $fields = array();
    // Set weight ordering and field position.
    if (!empty($params) && is_array($params)) {
      $tmp = array();
      $index = 0;
      foreach ($params as $label => $field) {
        // Get field weight.
        $weight = (!empty($field['weight'])) ? $field['weight'] : 0;
        // Ensure temporary weight array exists.
        if (empty($tmp[$weight])) {
          $tmp[$weight] = array();
        }
        // Add additional field values.
        $field['label'] = $label;
        $field['index'] = $index;
        // Build temporary weight orders array.
        $tmp[$weight][] = $field;
        // Increment field index counter.
        $index++;
      }
      // Order tmp array by weight key.
      ksort($tmp);
      // Build field array ordered by weight.
      foreach ($tmp as $w_fields) {
        foreach ($w_fields as $f) {
          $fields[] = $f;
        }
      }
    }
    return $fields;
  }
}
